@@ -55,26 +55,43 @@ def normalize_path(git, path):
     return str(path)
 
 # Determine a path and committish from args.
-def get_name_path_and_refname(git, gp, clargs):
+def get_name_branch_path_and_refname(git, gp, clargs):
     """Given a Project and worktree command-line arguments <name-or-path> and
-    <committish>, determine an appropriate worktree name, a path based on the
-    name and refname based on the name.  If one or the other of <name-or-path>
-    or <committish> is not provided, figure it out from the provided value.  If
-    neither <name-or-path> nor <committish> is provided, raise an exception.
+    <committish>, determine an appropriate worktree name, a branch for the
+    worktree, a path based on the name and refname based on the name.  If one or
+    the other of <name-or-path> or <committish> is not provided, figure it out
+    from the provided value.  If neither <name-or-path> nor <committish> is
+    provided, raise an exception.
 
     """
     name = str(Path(clargs.path).name)
+    branch = name
+    # If the path is not absolute, try creating a branch named as a subpath,
+    # starting either from the top or after the last .. component.
+    namepath = Path(clargs.path)
+    if not namepath.is_absolute():
+        parts = namepath.parts
+        for i, v in enumerate(reversed(parts)):
+            if v == '..':
+                oi = len(parts) - i - 1
+                namepath = Path(parts[oi+1])
+                for i in range(oi+2, len(parts)):
+                    namepath = namepath.joinpath(parts[i])
+                break
+        branch = str(namepath)
     path = normalize_path(git, clargs.path)
     refname = git.committish_to_refname('HEAD')
     if hasattr(clargs, 'committish') and clargs.committish:
         refname = git.committish_to_refname(clargs.committish)
 
-    return name, path, refname
+    return name, branch, path, refname
 
 # worktree add
 def command_worktree_add(git, gitproject, project, clargs):
     """Implement git-project worktree add."""
-    name, path, refname = get_name_path_and_refname(git, gitproject, clargs)
+    name, newbranch, path, refname = get_name_branch_path_and_refname(git,
+                                                                      gitproject,
+                                                                      clargs)
 
     branch = git.refname_to_branch_name(refname)
     branch_point = refname
@@ -87,9 +104,9 @@ def command_worktree_add(git, gitproject, project, clargs):
     if hasattr(clargs, 'branch') and clargs.branch:
         branch = clargs.branch
         git.create_branch(branch, branch_point)
-    elif name != branch:
-        branch = name
-        if not git.committish_exists(name):
+    elif newbranch != branch:
+        branch = newbranch
+        if not git.committish_exists(branch):
             git.create_branch(branch, branch_point)
 
     worktree = Worktree.get(git,
@@ -450,27 +467,18 @@ class WorktreePlugin(Plugin):
         unique main branch.
 
         """
-        main = ''
-        nonmain_branches = []
-        for refname in git.iterrefnames(['refs/heads']):
-            if refname == 'refs/heads/master':
-                if not main:
-                    main = refname
-            if refname == 'refs/heads/main':
-                main = refname
-            else:
-                nonmain_branches.append(refname)
+        main = git.get_main_branch()
+        if main:
+            return git.branch_name_to_refname(main)
+
+        branches = [branch for branch in git.iterrefnames(['refs/heads'])]
+        while True:
+            for refname in branches:
+                print(git.refname_to_branch_name(refname))
+            main = input('No unique main branch found, enter branch to use as main: ')
+            if git.branch_name_to_refname(main) in branches:
+                break
 
-        if not main:
-            if len(nonmain_branches) == 1:
-                main = nonmain_branches[0]
-            else:
-                while True:
-                    for refname in nonmain_branches:
-                        print(git.refname_to_branch_name(refname))
-                    main = input('No unique main branch found, enter branch to use as main: ')
-                    if git.branch_name_to_refname(main) in nonmain_branches:
-                        break
         return git.branch_name_to_refname(main)
 
     def _rewrite_bare_refspects(self, p_git):
